# Generated by Django 2.2.2 on 2019-06-28 19:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("edc_action_item", "0019_auto_20190627_2257")]

    operations = [
        migrations.AlterModelOptions(name="actiontype", options={"ordering": ["name"]}),
        migrations.AddIndex(
            model_name="actiontype",
            index=models.Index(fields=["name"], name="edc_action__name_f674a7_idx"),
        ),
    ]
