# Generated by Django 2.2.2 on 2019-06-28 19:13

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("edc_action_item", "0020_auto_20190628_2113")]

    operations = [
        migrations.RemoveIndex(model_name="actionitem", name="edc_action__action__b19a08_idx"),
        migrations.AddIndex(
            model_name="actionitem",
            index=models.Index(
                fields=[
                    "action_identifier",
                    "action_type",
                    "status",
                    "report_datetime",
                ],
                name="edc_action__action__fe58cb_idx",
            ),
        ),
    ]
