# Generated by Django 3.0.6 on 2020-05-28 02:20

from django.db import migrations

import edc_action_item.models.action_type


class Migration(migrations.Migration):

    dependencies = [
        ("edc_action_item", "0024_auto_20191024_1000"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="actiontype",
            managers=[
                ("objects", edc_action_item.models.action_type.ActionTypeManager()),
            ],
        ),
    ]
