# Generated by Django 2.2.5 on 2019-10-07 03:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("edc_action_item", "0022_auto_20190628_2136")]

    operations = [
        migrations.AlterField(
            model_name="actionitem",
            name="subject_identifier",
            field=models.CharField(max_length=50),
        ),
        migrations.AlterField(
            model_name="historicalactionitem",
            name="subject_identifier",
            field=models.CharField(max_length=50),
        ),
    ]
